@@ -64,6 +64,7 @@ static fft_data * FFT1, * FFT2, * FFT3;	// data for three fft's		WB4JFI ADD thir
 static fft_data * ptWriteFft;		// Write the current samples to this fft
 static double * fft_avg;		// Array to average the FFT
 static double * fft_window;		// Window for FFT data
+static int use_remove_dc=1;		// Remove DC from samples
 
 static PyObject * QuiskError;		// Exception for this module
 static PyObject * pyApp;		// Application instance
@@ -1036,8 +1037,9 @@ int quisk_read_rx_udp(complex * samp)	// Read samples from UDP
                		//	(int)(360.0 / 2 / M_PI * atan2(cimag(dc_average), creal(dc_average))));
 		}
 	}
-	for (i = 0; i < nSamples; i++)	// Correction for DC offset in samples
-		samp[i] -= dc_average;
+	if (use_remove_dc)
+		for (i = 0; i < nSamples; i++)	// Correction for DC offset in samples
+			samp[i] -= dc_average;
 	return nSamples;
 }
 
@@ -1316,6 +1318,7 @@ static PyObject * get_graph(PyObject * self, PyObject * args)
 		return Py_None;
 	}
 	if ( ! use_fft) {		// return raw data, not FFT
+		use_remove_dc = 0;	// No DC removal when returning raw data
 		tuple2 = PyTuple_New(data_width);
 		for (i = 0; i < data_width; i++)
 			PyTuple_SetItem(tuple2, i,
@@ -1323,6 +1326,7 @@ static PyObject * get_graph(PyObject * self, PyObject * args)
 		ptFft->status = EMPTY;
 		return tuple2;
 	}
+	use_remove_dc = 1;
 	// Continue with FFT calculation
 	for (i = 0; i < fft_size; i++)		// multiply by window
 		ptFft->samples[i] *= fft_window[i];
